@@ -76,11 +76,7 @@
 #' select the length of running window with the k_running_window argument.
 #' @param k_running_window the length of running window for temporal stability check.
 #' Applicable only if temporal_stability argument is set to running window.
-#' @param k integer, number of breaks (splits) for temporal stability and cross validation
-#' analysis.
-#' @param cross_validation_type character string, specifying, how to perform cross validation
-#' between the optimal selection and response variables. If the argument is set to "blocked",
-#' years will not be shuffled. If the argument is set to "randomized", years will be shuffled.
+#' @param k integer, number of breaks (splits) for temporal stability
 #' @param subset_years a subset of years to be analyzed. Should be given in the form of
 #' subset_years = c(1980, 2005)
 #' @param plot_specific_window integer representing window width to be displayed
@@ -122,6 +118,11 @@
 #' in method "Friedman" (see dplR R package).
 #' @param dc_difference	a logical flag. Compute residuals by substraction if TRUE,
 #' otherwise use division (see dplR R package).
+#' @param pcor_na_use an optional character string giving a method for computing
+#' covariances in the presence of missing values for partial correlation
+#' coefficients. This must be (an abbreviation of) one of the strings "all.obs",
+#' "everything", "complete.obs", "na.or.complete", or "pairwise.complete.obs"
+#' (default). See also the documentation for the base partial.r in psych R package
 #'
 #' @return a list with 15 elements:
 #' \enumerate{
@@ -133,7 +134,7 @@
 #'  \item $optimized_return_all - a data frame with aggregated monthly data, that returned the optimal result for the entire env_data_primary (and not only subset of analysed years)
 #'  \item $transfer_function - a ggplot object: scatter plot of optimized return and a transfer line of the selected method
 #'  \item $temporal_stability - a data frame with calculations of selected metric for different temporal subsets
-#'  \item $cross_validation - a data frame with cross validation results
+#'  \item $cross_validation - not available for partial correlation method
 #'  \item $plot_heatmap - ggplot2 object: a heatmap of calculated metrics
 #'  \item $plot_extreme - ggplot2 object: line plot of a row with the highest value in a matrix of calculated metrics
 #'  \item $plot_specific - ggplot2 object: line plot of a row with a selected window width in a matrix of calculated metrics
@@ -180,7 +181,7 @@
 #' plot(example_basic, type = 3)
 #' example_basic$optimized_return
 #' example_basic$optimized_return_all
-#'
+#' example_basic$temporal_stability
 #'
 #' # 2 Extended example
 #' example_extended <- monthly_response_seascorr(response = data_MVA,
@@ -194,11 +195,11 @@
 #'    tidy_env_data_primary = FALSE,
 #'    tidy_env_data_control = TRUE)
 #'
-#' summary(example_fixed_width)
-#' plot(example_fixed_width, type = 1)
-#' plot(example_fixed_width, type = 2)
-#' example_fixed_width$optimized_return
-#' example_fixed_width$optimized_return_all
+#' summary(example_extended)
+#' plot(example_extended, type = 1)
+#' plot(example_extended, type = 2)
+#' example_extended$optimized_return
+#' example_extended$optimized_return_all
 #'
 #' }
 
@@ -214,7 +215,7 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                            aggregate_function_env_data_primary = 'mean',
                            aggregate_function_env_data_control = 'mean',
                            temporal_stability_check = "sequential", k = 2,
-                           k_running_window = 30, cross_validation_type = "blocked",
+                           k_running_window = 30,
                            subset_years = NULL, plot_specific_window = NULL,
                            ylimits = NULL, seed = NULL, tidy_env_data_primary = FALSE,
                            tidy_env_data_control = FALSE,  boot = FALSE, boot_n = 1000,
@@ -229,7 +230,8 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                            dc_constrain.nls = c("never", "when.fail", "always"),
                            dc_span = "cv",
                            dc_bass = 0,
-                           dc_difference = FALSE) {
+                           dc_difference = FALSE,
+                           pcor_na_use = "pairwise.complete") {
 
   ##############################################################################
   # 1 day interval is organized
@@ -352,10 +354,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
    upper_limit = 12
  }
 
-
- # Here I define the method = "cor", so the functionality is ensured
- method = "cor"
-
  # If there is a column name samp.depth in response data frame, warning is given
  if ("samp.depth" %in% colnames(response)){
 
@@ -431,8 +429,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
 
 
-
-
   # PART 1 - general data arrangements, warnings and stops
   # Both bojects (response and env_data_primary) are converted to data frames
   response <- data.frame(response)
@@ -448,7 +444,12 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   # with the exception, when row_names_subset is set to TRUE
   # Stop message in case both data frames do not have the same length
   if (nrow(response) !=  nrow(env_data_primary) & row_names_subset == FALSE)
-    stop("Length of env_data_primary and response records differ")
+    stop(paste0("Length of env_data_primary and response records differ",
+                " You can use row_names_subset = TRUE"))
+
+  if (nrow(response) !=  nrow(env_data_control) & row_names_subset == FALSE)
+    stop(paste0("Length of env_data_control and response records differ",
+                " You can use row_names_subset = TRUE"))
 
 
 
@@ -494,9 +495,8 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   if (fixed_width < 0 | fixed_width > 24)
     stop("fixed_width should be between 1 and 12 (24=")
 
-  # Stop in case of method == "cor" and ncol(proxies) > 1
   # Correlations could be calculated only for one variable
-  if (method == "cor" & ncol(response) > 1)
+  if (ncol(response) > 1)
     stop(paste("More than 1 variable in response data frame not suitable ",
   "for 'pcor' method'"))
 
@@ -523,6 +523,53 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     }
   }
 
+  # Warn users in case of missing values (selected threshold is 8 months)
+  # A) env_data_primary
+  env_temp_primary <- env_data_primary[row.names(env_data_primary) %in% row.names(response),]
+
+  if (!is.null(subset_years)){
+    lower_subset <- subset_years[1]
+    upper_subset <- subset_years[2]
+
+    subset_seq <- seq(lower_subset, upper_subset)
+    env_temp_primary <- subset(env_temp_primary, row.names(env_temp_primary) %in% subset_seq)
+  }
+
+  na_problem <- data.frame(na_sum = rowSums(is.na(env_temp_primary)))
+  na_problem <- na_problem[na_problem$na_sum > 8, , F]
+  problematic_years <- paste0(row.names(na_problem), sep = "", collapse=", ")
+
+  if (nrow(na_problem) > 0){
+
+    warning(paste0("Problematic years with missing values are present in env_data_primary: ", problematic_years))
+
+  }
+
+  # B) env_data_control
+
+  env_temp_conotrol <- env_data_control[row.names(env_data_control) %in% row.names(response),]
+
+  if (!is.null(subset_years)){
+    lower_subset <- subset_years[1]
+    upper_subset <- subset_years[2]
+
+    subset_seq <- seq(lower_subset, upper_subset)
+    env_temp_conotrol <- subset(env_temp_conotrol, row.names(env_temp_conotrol) %in% subset_seq)
+  }
+
+  na_problem <- data.frame(na_sum = rowSums(is.na(env_temp_conotrol)))
+  na_problem <- na_problem[na_problem$na_sum > 8, , F]
+  problematic_years <- paste0(row.names(na_problem), sep = "", collapse=", ")
+
+  if (nrow(na_problem) > 0){
+
+    warning(paste0("Problematic years with missing values are present in env_data_control: ", problematic_years))
+
+  }
+
+  ##############################################################################
+
+
   # Data manipulation
   # If use.previous == TRUE, env_data_primary data has to be rearranged accordingly
   if (previous_year == TRUE) {
@@ -550,19 +597,12 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     row.names(env_data_control) <- row_names_current
     env_data_control_original <- env_data_control
 
-    response$yearABC <- row.names(response)
-    response <- dplyr::arrange(response, desc(yearABC))
-    response <- years_to_rownames(response, "yearABC")
-    response <- data.frame(response[-nrow(response),,F ])
-    response <- data.frame(response)
-    response_original <- response
-
     }
 
-  # If row_names_subset == TRUE, data is subseted and ordered based on matching
+  # If row_names_subset == TRUE, data is subset and ordered based on matching
   # row.names. Additionally, number of characters in row.names is checked.
   # There should be at least three characters (assuming years before 100 will
-  # never be analysed, there is no such environmental data avaliable)
+  # never be analysed, there is no such environmental data available)
   if (row_names_subset == TRUE & nchar(row.names(env_data_primary)[1]) >= 3){
 
     env_data_primary$yearABC <- row.names(env_data_primary)
@@ -654,7 +694,7 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
     if (any(!(subset_seq %in% row.names(response)))){
 
-      stop(paste0("Undefined columns selected. You subset years don't exist",
+      stop(paste0("Undefined columns selected. Subset years don't exist",
                   " in the response data frame. Change the subset_years argument"))
     }
 
@@ -684,13 +724,10 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                 "Problematic year is ", prob_year))
     }
 
-  # PART 2 - Based on the selected function arguments, different chunks of code
-  # will be used. For demonstration:
-  # A) Chunks are used if fixed.withd != 0
-    # A.1 method == "cor"
 
-  # B) Chunks are used if fixed.withd == 0
-    # B.1 method == "cor"
+  # PART 2 - the calculation of day-wise correlations
+  # A) fixed window approach
+  # B) Variable window approach
 
   # these are lists for climate and and holder for saving mm1 and mm2
   list_climate_primary <- list()
@@ -699,11 +736,11 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   mm1 <- 1
   mm2 <- 1
 
-  # A.1 method = "cor"
-  if (fixed_width != 0 & method == "cor") {
+  # A) The fixed window approach
+  if (fixed_width != 0) {
 
       # This is an empty matrix, currently filled with NA's
-      # Latter, calculations will be stored in this matrix
+      # Latter, calculations will be saved in this matrix
       if (reference_window == 'start'){
         temporal_matrix <- matrix(NA, nrow = 1,
                                   ncol = (ncol(env_data_primary) - fixed_width) + 1)
@@ -718,20 +755,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     temporal_matrix_lower <- temporal_matrix
     temporal_matrix_upper <- temporal_matrix
 
-
-
-
-
     if (fixed_width != max_window){
       pb <- txtProgressBar(min = 0, max = (ncol(env_data_primary) - fixed_width - offset_end - offset_start + 1),
                            style = 3)}
 
       b = 0
 
-      # An iterating loop. In each itteration x is calculated and represents
+      # An iterating loop. In each iteration x is calculated and represents
       # response (dependent) variable. X is a moving average. Window width of
-      # a moving window is fixed_width. Next, statistical metric is calculated
-      # based on a selected method (cor, lm or brnn). Calculation is stored in
+      # a moving window is fixed_width. Next, partial correlation is stored in
       # temporal matrix.
 
       for (j in (0 + offset_start -1): (ncol(env_data_primary) - max((fixed_width + offset_end), offset_end))) {
@@ -753,11 +785,11 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                                  (1 + j): (j + fixed_width)]), na.rm = TRUE)
         } else {
 
-          stop(paste0("aggregate function for is env_data_primary", aggregate_function_env_data_primary, ". Instead it should be mean, median or sum."))
+          stop(paste0("aggregate function for is env_data_primary", aggregate_function_env_data_primary,
+                      ". Instead it should be mean, median or sum."))
 
         }
 
-
         if (aggregate_function_env_data_control == 'median'){
 
           x2 <- apply(data.frame(env_data_control[1:nrow(env_data_control),
@@ -772,10 +804,10 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
           x2 <- rowMeans(data.frame(env_data_control[1:nrow(env_data_control),
                                           (1 + j): (j + fixed_width)]), na.rm = TRUE)
         } else {
-          stop(paste0("aggregate function for env_data_control is ", aggregate_function_env_data_control, ". Instead it should be mean, median or sum."))
+          stop(paste0("aggregate function for env_data_control is ", aggregate_function_env_data_control,
+                      ". Instead it should be mean, median or sum."))
         }
 
-
         if (!is.null(dc_method)){
 
           x1 <- dplR::detrend(data.frame(x1), method = dc_method, nyrs = dc_nyrs, f = dc_f,
@@ -788,7 +820,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
         }
 
-
         if (!is.null(dc_method)){
 
           x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
@@ -804,7 +835,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
         my_temporal_data <- cbind(response[, 1], x1, x2)
         colnames(my_temporal_data) <- c("x", "y", "z")
 
-
         x1_list <- x1
         colnames(x1_list) <- paste0(j + 1, "_" ,j + fixed_width)
         row.names(x1_list) <- row.names(env_data_primary)
@@ -817,10 +847,10 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
         list_climate_control[[mm2]] <- x2_list
         mm2 = mm2 + 1
 
-
         if (boot == FALSE){
 
-          temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use="pairwise",method = pcor_method)[2]
+          temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z",
+                                            use=pcor_na_use,method = pcor_method)[2]
 
           if (reference_window == 'start'){
             temporal_matrix[1, j + 1] <- as.numeric(temporal_correlation)[1]
@@ -900,7 +930,7 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
       if (fixed_width != max_window){close(pb)}
 
      # temporal_matrix is given rownames and colnames. Rownames represent a
-     # window width used fot calculations. Colnames represent the position of
+     # window width used for calculations. Colnames represent the position of
      # moving window in a original env_data_primary data frame.
       row.names(temporal_matrix) <- fixed_width
       row.names(temporal_matrix_lower) <- fixed_width
@@ -916,12 +946,11 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   # B fixed_width == 0, in this case, lower_limit and upper_limit arguments
   # will be used to define window width of a moving window.
-  # B.1 method == "cor"
 
-  if (fixed_width == 0 & method == "cor") {
+  if (fixed_width == 0) {
 
     # This is an empty matrix, currently filled with NA's
-    # Latter, calculations will be stored in this matrix
+    # Latter, calculations will be saved in this matrix
 
     if (reference_window == 'start'){
     temporal_matrix <- matrix(NA, nrow = (upper_limit - lower_limit + 1),
@@ -935,15 +964,14 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
                                                  1 + lower_limit/2 ),0))
     }
 
-  # An iterating double loop: 1 outer loop) iterating from lower_limit :
-  # upper_limit defines windo.width used for a moving window. 2) inner loop
+  # An iterating double loop: 1 outer loop) iterating from lower_limit to
+  # upper_limit defines window width used for a moving window. 2) inner loop
   # defines the starting position of a moving window.
-  # In each itteration, x is calculated and represents a response (dependent)
+  # In each iteration, x is calculated and represents a response (dependent)
   # variable. x is a moving average, based on rowMeans/apply function.
-  # Next, statistical metric is calculated based on a selected method (cor,
-  # lm or brnn). Calculation is stored in temporal matrix in a proper place.
-  # The position of stored calculation is informative later used for
-  # indiciating optimal values.
+  # Next, statistical metric is calculated based on a selected method (pcor).
+  # Calculation is stored in temporal matrix in a proper place. The position of
+  # stored calculation is informative later used for indicating optimal values.
 
     temporal_matrix_lower <- temporal_matrix
     temporal_matrix_upper <- temporal_matrix
@@ -952,10 +980,8 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
       pb <- txtProgressBar(min = 0, max = (upper_limit - lower_limit), style = 3)
     }
 
-
   b = 0
 
-
   for (K in lower_limit:upper_limit) {
 
     b = b + 1
@@ -998,16 +1024,20 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
       if (aggregate_function_env_data_control == 'median'){
 
         if (K == 1){
+
           x2 <- env_data_control[,K+j]
-        } else {
+
+          } else {
 
           x2 <- apply(data.frame(env_data_control[1:nrow(env_data_control), (1 + j) : (j + K)]),1 , median, na.rm = TRUE)}
 
       } else if (aggregate_function_env_data_control == 'sum'){
 
         if (K == 1){
+
           x2 <- env_data_control[,K+j]
-        } else {
+
+          } else {
 
           x2 <- apply(data.frame(env_data_control[1:nrow(env_data_control), (1 + j) : (j + K)]),1 , sum, na.rm = TRUE)}
 
@@ -1015,8 +1045,10 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
       else if (aggregate_function_env_data_control == 'mean'){
 
         if (K == 1){
+
           x2 <- env_data_control[,K+j]
-        } else {
+
+          } else {
 
           x2 <- rowMeans(data.frame(env_data_control[1:nrow(env_data_control), (1 + j) : (j + K)]), na.rm = T)}
 
@@ -1038,7 +1070,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
       }
 
-
       if (!is.null(dc_method)){
 
         x2 <- dplR::detrend(data.frame(x2), method = dc_method, nyrs = dc_nyrs, f = dc_f,
@@ -1054,7 +1085,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
        my_temporal_data <- cbind(response[, 1], x1, x2)
        colnames(my_temporal_data) <- c("x", "y", "z")
 
-
        x1_list <- x1
        colnames(x1_list) <- paste0(j + 1, "_" ,j + K)
        row.names(x1_list) <- row.names(env_data_primary)
@@ -1069,15 +1099,22 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
        if (boot == FALSE){
 
-         temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use="pairwise",method = pcor_method)[2]
+         temporal_correlation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z",
+                                           use=pcor_na_use,method = pcor_method)[2]
 
          if (reference_window == 'start'){
+
            temporal_matrix[(K - lower_limit) + 1, j + 1] <- as.numeric(temporal_correlation)[1]
-         } else if (reference_window == 'end'){
-           temporal_matrix[(K - lower_limit) + 1, j + K] <- as.numeric(temporal_correlation)[1]
-         } else if (reference_window == 'middle'){
-           temporal_matrix[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- as.numeric(temporal_correlation)[1]
-         }
+
+           } else if (reference_window == 'end'){
+
+             temporal_matrix[(K - lower_limit) + 1, j + K] <- as.numeric(temporal_correlation)[1]
+
+             } else if (reference_window == 'middle'){
+
+               temporal_matrix[(K - lower_limit) + 1, round2(j + 1 + K/2, 0)] <- as.numeric(temporal_correlation)[1]
+
+               }
 
        } else if (boot == TRUE){
 
@@ -1158,7 +1195,6 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   row.names(temporal_matrix_lower) <- temporal_rownames
   row.names(temporal_matrix_upper) <- temporal_rownames
 
-
   temporal_colnames <- as.vector(seq(from = 1,
                                      to = ncol(temporal_matrix), by = 1))
   colnames(temporal_matrix) <- temporal_colnames
@@ -1166,29 +1202,20 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   colnames(temporal_matrix_upper) <- temporal_colnames
   }
 
-  # To enhance the visualisation, insignificant values
+  # To enhance the visualization, insignificant values
   # are removed if remove_insignificant == TRUE
   if (remove_insignificant == TRUE){
     critical_threshold_cor <- critical_r(nrow(response), alpha = alpha)
     critical_threshold_cor2 <- critical_threshold_cor ^ 2
 
-  # 1 Method is correlation
-   if (method == "cor") {
-     temporal_matrix[abs(temporal_matrix) < abs(critical_threshold_cor)] <- NA
-  # 2 lm and brnn method
-      } else if (method == "lm" | method == "brnn") {
-    temporal_matrix[abs(temporal_matrix) < abs(critical_threshold_cor2)] <- NA
-      }
+    temporal_matrix[abs(temporal_matrix) < abs(critical_threshold_cor)] <- NA
 
-    if(is.finite(mean(temporal_matrix, na.rm = TRUE)) == FALSE){
+  if(is.finite(mean(temporal_matrix, na.rm = TRUE)) == FALSE){
       stop("All calculations are insignificant! Please change the alpha argument.")
     }
 
   }
 
-
-
-
   ########################################################################
   # PART 4: Final list is being created and returned as a function output#
   ########################################################################
@@ -1491,7 +1518,7 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   }
 
-# Naredi conclusion
+# Final output list
 
   if (!is.null(dc_method)){
 
@@ -1536,17 +1563,10 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   my_temporal_data <- cbind(x1_full[,1], x1_full[,2], x1_full[,3])
   colnames(my_temporal_data) <- c("x", "y", "z")
-  test_calculation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use="pairwise",method = pcor_method)[2]
-
+  test_calculation <- partial.r(data=my_temporal_data, x=c("x","y"), y="z", use=pcor_na_use,method = pcor_method)[2]
 
   test_logical <- as.numeric(max_calculation) == as.numeric(test_calculation)
 
-#if (test_logical == FALSE){
-#  stop(paste0("Test calculation and max calculation do not match.",
-#       "Please contact the maintainer of the dendroTools R package"))
-#}
-
-
   # Element 5
   # Here we create the fifth element of the final list: Analysed period in the
   # form of min(year) - max(year), e.g. 1950 - 2015
@@ -1572,14 +1592,9 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
   lm_model = lm(optimized_return ~ proxy, data = transfer_data)
   full_range = data.frame(proxy = seq(from = min(response[,1]), to = max(response[,1]), length.out = 100))
 
-  if (method == "lm" | method == "cor"){
-    full_range$transfer_f = predict(lm_model, full_range)
-  }
-
-
   # String for titles
 
-    title_string <- "Partial Correlation Coefficients"
+  title_string <- "Partial Correlation Coefficients"
 
   # The definition of theme
   journal_theme <- theme_bw() +
@@ -1599,12 +1614,11 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
     p1 <- "No transfer function is created for two or more response variables"
   }
 
-
   #######################################################################
   ############## The temporal stability of optimized_return #############
   #######################################################################
 
-  dataset = data.frame(optimized_return =x1[,1], proxy = response)
+  dataset = x1_full
 
   empty_list = list()
   empty_list_period = list()
@@ -1614,11 +1628,12 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   # 1. Progressive stability check
   if (temporal_stability_check == "progressive"){
+
     foldi <- seq(1:k)
-    #foldi <- paste("fold_", foldi)
     folds <- cut(seq(1, nrow(dataset)), breaks = k, labels = FALSE)
 
-      for (m in 1:k){
+    for (m in 1:k){
+
       #Segement your data by fold using the which() function
       trainIndexes <- which(folds <= m, arr.ind = TRUE)
       dataset_temp <- dataset[trainIndexes, ]
@@ -1626,14 +1641,15 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
       MIN <- min(as.numeric(row.names(dataset_temp)))
       empty_list_period[[m]] <- paste(MIN, "-", MAKS)
 
-      if (method == "cor"){
-        calculation <- cor(dataset_temp[,1], dataset_temp[,2])
-        sig <- cor.test(dataset_temp[,1], dataset_temp[,2], method = pcor_method, exact = FALSE)$p.value
-        empty_list_significance[[m]] <- sig
-        empty_list[[m]] <- calculation
-        colname = "correlation"
-      }
-      }
+      par.r <- partial.r(data=dataset_temp, x=c(1,2), y=3, use=pcor_na_use,method = pcor_method)
+      calculation <- par.r[2]
+      sig <- corr.p(par.r,n = nrow(dataset_temp - 2))$p[2]
+
+      empty_list_significance[[m]] <- sig
+      empty_list[[m]] <- calculation
+      colname = "partial correlation"
+
+    }
     m1 <- do.call(rbind, empty_list)
     m2 <- do.call(rbind, empty_list_period)
     m3 <- do.call(rbind, empty_list_significance)
@@ -1645,35 +1661,37 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
   # 2. Sequential stability check
   if (temporal_stability_check == "sequential"){
-      foldi <- seq(1:k)
-      #foldi <- paste("fold_", foldi)
-      folds <- cut(seq(1, nrow(dataset)), breaks = k, labels = FALSE)
 
-      for (m in 1:k){
-        #Segement your data by fold using the which() function
-        trainIndexes <- which(folds == m, arr.ind = TRUE)
-        dataset_temp <- dataset[trainIndexes, ]
+    foldi <- seq(1:k)
+    folds <- cut(seq(1, nrow(dataset)), breaks = k, labels = FALSE)
 
-        MAKS <- max(as.numeric(row.names(dataset_temp)))
-        MIN <- min(as.numeric(row.names(dataset_temp)))
-        empty_list_period[[m]] <- paste(MIN, "-", MAKS)
+    for (m in 1:k){
 
-        if (method == "cor"){
-          calculation <- cor(dataset_temp[,1], dataset_temp[,2])
-          sig <- cor.test(dataset_temp[,1], dataset_temp[,2], method = pcor_method, exact = FALSE)$p.value
-          empty_list[[m]] <- calculation
-          empty_list_significance[[m]] <- sig
-          colname = "correlation"
+      #Segement your data by fold using the which() function
+      trainIndexes <- which(folds == m, arr.ind = TRUE)
+      dataset_temp <- dataset[trainIndexes, ]
 
-        }
-      }
-      m1 <- do.call(rbind, empty_list)
-      m2 <- do.call(rbind, empty_list_period)
-      m3 <- do.call(rbind, empty_list_significance)
+      MAKS <- max(as.numeric(row.names(dataset_temp)))
+      MIN <- min(as.numeric(row.names(dataset_temp)))
+      empty_list_period[[m]] <- paste(MIN, "-", MAKS)
 
-      temporal_stability <- data.frame(cbind(m2, format(round(m1, 3), nsmall = 3), format(round(m3, 4), nsmall = 3)))
-      colnames(temporal_stability) <-c("Period", colname, "p value")
-      temporal_stability
+      par.r <- partial.r(data=dataset_temp, x=c(1,2), y=3, use=pcor_na_use,method = pcor_method)
+      calculation <- par.r[2]
+      sig <- corr.p(par.r,n = nrow(dataset_temp - 2))$p[2]
+
+      empty_list_significance[[m]] <- sig
+      empty_list[[m]] <- calculation
+      colname = "partial correlation"
+
+    }
+
+    m1 <- do.call(rbind, empty_list)
+    m2 <- do.call(rbind, empty_list_period)
+    m3 <- do.call(rbind, empty_list_significance)
+
+    temporal_stability <- data.frame(cbind(m2, format(round(m1, 3), nsmall = 3), format(round(m3, 4), nsmall = 3)))
+    colnames(temporal_stability) <-c("Period", colname, "p value")
+    temporal_stability
 
   }
 
@@ -1699,29 +1717,26 @@ monthly_response_seascorr <- function(response, env_data_primary, env_data_contr
 
       dataset_temp <- dataset[(1+w):(k_running_window + w),]
       empty_list_datasets[[place_list]] <- dataset_temp
-
       MAKS <- max(as.numeric(row.names(dataset_temp)))
       MIN <- min(as.numeric(row.names(dataset_temp)))
       empty_list_period[[place_list]] <- paste(MIN, "-", MAKS)
-
       place_list <- place_list + 1
 
-
     }
 
-for (m in 1:length(empty_list_datasets)){
+    for (m in 1:length(empty_list_datasets)){
 
-  dataset_temp <- empty_list_datasets[[m]]
+      dataset_temp <- empty_list_datasets[[m]]
 
-  if (method == "cor"){
-    calculation <- cor(dataset_temp[,1], dataset_temp[,2])
-    sig <- cor.test(dataset_temp[,1], dataset_temp[,2], method = pcor_method, exact = FALSE)$p.value
-    empty_list[[m]] <- calculation
-    empty_list_significance[[m]] <- sig
-    colname = "correlation"
+      par.r <- partial.r(data=dataset_temp, x=c(1,2), y=3, use=pcor_na_use,method = pcor_method)
+      calculation <- par.r[2]
+      sig <- corr.p(par.r,n = nrow(dataset_temp - 2))$p[2]
 
-  }
-}
+      empty_list_significance[[m]] <- sig
+      empty_list[[m]] <- calculation
+      colname = "partial correlation"
+
+    }
     m1 <- do.call(rbind, empty_list)
     m2 <- do.call(rbind, empty_list_period)
     m3 <- do.call(rbind, empty_list_significance)
@@ -1729,109 +1744,20 @@ for (m in 1:length(empty_list_datasets)){
     temporal_stability <- data.frame(cbind(m2, format(round(m1, 3), nsmall = 3), format(round(as.numeric(m3), digits = 3), nsmall = 3)))
     colnames(temporal_stability) <-c("Period", colname, "p value")
     temporal_stability
-}
-
-
-
-
-  #########################################################################
-  ################## Out of sample estimates ##############################
-  #########################################################################
-
-  dataset = data.frame(optimized_return =x1[,1], proxy = response)
-
-  empty_list = list()
-  empty_list_period = list()
-
-  if (cross_validation_type == "blocked"){
-    dataset <- dataset
-  } else if (cross_validation_type == "randomized"){
-    dataset <- dataset[sample(nrow(dataset)), ]
-  } else (stop(paste("The cross_validation_type is not selected correctly! It is ", cross_validation_type,
-    ". It should be 'blocked' or 'randomized'!", sep = "")))
-
-     foldi <- seq(1:k)
-     #foldi <- paste("fold_", foldi)
-     folds <- cut(seq(1, nrow(dataset)), breaks = k, labels = FALSE)
-     bl = 1
-
-    for (m in 1:k){
-      #Segement your data by fold using the which() function
-      testIndexes <- which(folds == m, arr.ind = TRUE)
-      test <- dataset[testIndexes, ]
-      train <- dataset[-testIndexes, ]
-
-      MAKS <- max(as.numeric(row.names(train)))
-      MIN <- min(as.numeric(row.names(train)))
-      empty_list_period[[bl]] <- paste(MIN, "-", MAKS)
-      bl <- bl + 1
-
-      MAKS <- max(as.numeric(row.names(test)))
-      MIN <- min(as.numeric(row.names(test)))
-      empty_list_period[[bl]] <- paste(MIN, "-", MAKS)
-      bl <- bl + 1
-
-      if (method == "lm" | method == "cor"){
-        MLR <- lm(optimized_return ~ ., data = train)
-        train_predicted <- predict(MLR, train)
-        test_predicted <- predict(MLR, test)
-        train_observed <- train[, 1]
-        test_observed <- test[, 1]
-        calculations <- calculate_metrics(train_predicted, test_predicted,
-                                          train_observed, test_observed, test = test,
-                                          formula = optimized_return ~ ., digits = 15)
-
-        empty_list[[m]] <- calculations
-      }
-
-    }
-    m1 <- do.call(rbind, empty_list)
-    # m1 <- m1[, -c(3, 4, 7)]
-    m2 <- do.call(rbind, empty_list_period)
-
-    cross_validation <- cbind(Years = m2, m1)
-    cross_validation$Period <- c("Calibration", "Validation")
-    cross_validation$CV <- rep(1:k, each = 2)
-    row.names(cross_validation) <- NULL
-
-    if (cross_validation_type == "blocked"){
-      cross_validation <- dplyr::select(cross_validation, CV, Period, Years, cor, RMSE, RRSE, d, RE, CE, DE)
-    }
-    if (cross_validation_type == "randomized"){
-      cross_validation <- dplyr::select(cross_validation, CV, Period, cor, RMSE, RRSE, d, RE, CE, DE)
-    }
-
-
+  }
 
   ################################################################
   #### Here the final list is being filled with six elements #####
   ################################################################
 
-
-
-
-  # When metohod == "cor", different final_list is created
-  if (method == "lm" | method == "brnn") {
-    final_list <- list(calculations = temporal_matrix, method = method,
-                       metric = metric, analysed_period = analysed_period,
-                       optimized_return = x1_full,
-                       optimized_return_all = x1_full_original,
-                       transfer_function = p1, temporal_stability = temporal_stability,
-                       cross_validation = cross_validation,
-                       aggregated_climate_primary = do.call(cbind, list_climate_primary),
-                       aggregated_climate_control = do.call(cbind, list_climate_control))
-  }
-
-  if (method == "cor"){
     final_list <- list(calculations = temporal_matrix, method = "pcor",
                        metric = pcor_method, analysed_period = analysed_period,
                        optimized_return = x1_full,
                        optimized_return_all = x1_full_original,
                        transfer_function = p1, temporal_stability = temporal_stability,
-                       cross_validation = cross_validation,
+                       cross_validation = NA,
                        aggregated_climate_primary = do.call(cbind, list_climate_primary),
                        aggregated_climate_control = do.call(cbind, list_climate_control))
-  }
 
     plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window, type = "monthly")
     plot_extremeA <- plot_extreme(final_list, ylimits = ylimits, reference_window = reference_window, type = "monthly")
@@ -1855,14 +1781,12 @@ for (m in 1:length(empty_list_datasets)){
                                       reference_window = reference_window)
     } else (plot_specificA <- "Selected plot_specific_window is not avaliable. No plot_specific is made!")
 
-    # Here, for the sake of simplicity, we create final list again
-    if (method == "lm" | method == "brnn") {
       final_list <- list(calculations = temporal_matrix, method = "pcor",
                          metric = pcor_method, analysed_period = analysed_period,
                          optimized_return = x1_full,
                          optimized_return_all = x1_full_original,
                          transfer_function = p1, temporal_stability = temporal_stability,
-                         cross_validation = cross_validation,
+                         cross_validation = NA,
                          plot_heatmap = plot_heatmapA,
                          plot_extreme = plot_extremeA,
                          plot_specific = plot_specificA,
@@ -1873,27 +1797,6 @@ for (m in 1:length(empty_list_datasets)){
                          boot_upper = temporal_matrix_upper,
                          aggregated_climate_primary = do.call(cbind, list_climate_primary),
                          aggregated_climate_control = do.call(cbind, list_climate_control))
-    }
-
-    if (method == "cor"){
-      final_list <- list(calculations = temporal_matrix, method = "pcor",
-                         metric = pcor_method, analysed_period = analysed_period,
-                         optimized_return = x1_full,
-                         optimized_return_all = x1_full_original,
-                         transfer_function = p1, temporal_stability = temporal_stability,
-                         cross_validation = cross_validation,
-                         plot_heatmap = plot_heatmapA,
-                         plot_extreme = plot_extremeA,
-                         plot_specific = plot_specificA,
-                         PCA_output = PCA_result,
-                         type = "monthly",
-                         reference_window = reference_window,
-                         boot_lower = temporal_matrix_lower,
-                         boot_upper = temporal_matrix_upper,
-                         aggregated_climate_primary = do.call(cbind, list_climate_primary),
-                         aggregated_climate_control = do.call(cbind, list_climate_control)
-                         )
-    }
 
     class(final_list) <- "dmrs"
 
